@@ -19,16 +19,19 @@
 #'   the number of observations and degrees of freedom to the nearest integer,
 #'   p-values are styled with `style_pvalue()` and the remaining statistics
 #'   are styled with `style_sigfig(x, digits = 3)`
-#' @param glance_fun function that returns model statistics. Default is
-#' `broom::glance()` for most model obejcts, and
-#' `broom::glance(mice::pool())` for MICE 'mira' models.
-#' Custom functions must return a single row tibble.
-#' @param sep1 Separator between statistic name and statistic.
-#' Default is `" = "`, e.g. `"R2 = 0.456"`
-#' @param sep2 Separator between statistics. Default is `"; "`
-#' @param text_interpret String indicates whether source note text
-#' will be interpreted with
-#' [gt::md()] or [gt::html()]. Must be `"md"` (default) or `"html"`.
+#' @param glance_fun (`function`)\cr
+#'   function that returns model statistics. Default is
+#'   `glance_fun()` (which is `broom::glance()` for most model objects).
+#'   Custom functions must return a single row tibble.
+#' @param sep1 (`string`)\cr
+#'   Separator between statistic name and statistic.
+#'   Default is `" = "`, e.g. `"R2 = 0.456"`
+#' @param sep2 (`string`)\cr
+#'   Separator between statistics. Default is `"; "`
+#' @param text_interpret (`string`)\cr
+#'   String indicates whether source note text
+#'   will be interpreted with
+#'   [gt::md()] or [gt::html()]. Must be `"md"` (default) or `"html"`.
 #'
 #' @return gtsummary table
 #' @name add_glance
@@ -43,7 +46,7 @@
 #'   modify_table_body(~.x %>% arrange(row_type == "glance_statistic"))
 #' ````
 #'
-#' @examples
+#' @examplesIf (identical(Sys.getenv("NOT_CRAN"), "true") || identical(Sys.getenv("IN_PKGDOWN"), "true")) && gtsummary:::is_pkg_installed("cardx")
 #' mod <- lm(age ~ marker + grade, trial) |> tbl_regression()
 #'
 #' # Example 1 ----------------------------------
@@ -72,20 +75,14 @@ add_glance_table <- function(x,
                                  any_of("p.value") ~ label_style_pvalue(digits = 1),
                                  c(where(is.integer), starts_with("df")) ~ label_style_number()
                                ),
-                             glance_fun = broom::glance) {
+                             glance_fun = glance_fun_s3(x$inputs$x)) {
   # check inputs ---------------------------------------------------------------
   set_cli_abort_call()
   updated_call_list <- c(x$call_list, list(add_glance_table = match.call()))
-  check_pkg_installed("broom", reference_pkg = "gtsummary")
+  check_pkg_installed("broom")
   check_not_missing(x)
   check_class(x, "tbl_regression")
 
-  # use a modified glance for mice models --------------------------------------
-  if (missing(glance_fun) && inherits(x$inputs$x, "mice")) {
-    check_pkg_installed("mice", reference_pkg = "gtsummary")
-    glance_fun <- \(x) broom::glance(mice::pool(x))
-  }
-
   # calculate and prepare the glance function results --------------------------
   lst_prep_glance <-
     .prep_glance_statistics(
@@ -131,24 +128,19 @@ add_glance_source_note <- function(x,
                                        any_of("p.value") ~ label_style_pvalue(digits = 1),
                                        c(where(is.integer), starts_with("df")) ~ label_style_number()
                                      ),
-                                   glance_fun = broom::glance,
+                                   glance_fun = glance_fun_s3(x$inputs$x),
                                    text_interpret = c("md", "html"),
                                    sep1 = " = ", sep2 = "; ") {
   # check inputs ---------------------------------------------------------------
   set_cli_abort_call()
   updated_call_list <- c(x$call_list, list(add_glance_source_note = match.call()))
-  check_pkg_installed("broom", reference_pkg = "gtsummary")
+  check_pkg_installed("broom")
   check_not_missing(x)
   check_class(x, "tbl_regression")
   text_interpret <- arg_match(text_interpret)
   check_string(sep1)
   check_string(sep2)
-
-  # use a modified glance for mice models --------------------------------------
-  if (missing(glance_fun) && inherits(x$inputs$x, "mice")) {
-    check_pkg_installed("mice", reference_pkg = "gtsummary")
-    glance_fun <- \(x) broom::glance(mice::pool(x))
-  }
+  text_interpret <- arg_match(text_interpret, error_call = get_cli_abort_call())
 
   # calculate and prepare the glance function results --------------------------
   lst_prep_glance <-
@@ -170,9 +162,13 @@ add_glance_source_note <- function(x,
   }
 
   # compile stats into source note ---------------------------------------------
-  x$table_styling$source_note <-
-    paste(lst_prep_glance$df_glance$label, lst_prep_glance$df_glance$estimate_fmt, sep = sep1, collapse = sep2)
-  attr(x$table_styling$source_note, "text_interpret") <- match.arg(text_interpret)
+  x <-
+    modify_source_note(
+      x,
+      source_note =
+        paste(lst_prep_glance$df_glance$label, lst_prep_glance$df_glance$estimate_fmt, sep = sep1, collapse = sep2),
+      text_interpret = text_interpret
+    )
 
   # returning gtsummary table --------------------------------------------------
   x$call_list <- updated_call_list
