@@ -225,6 +225,16 @@ table_styling_to_gt_calls <- function(x, ...) {
     set_names(x$table_styling$header$column) %>%
     {call2(expr(gt::cols_label), !!!.)} # styler: off
 
+  # remove_line_breaks ---------------------------------------------------------
+  # We include line breaks in many tables by default in the headers
+  # This removes them if rendering to PDF. Hopefully we can remove this soon.
+  gt_calls[["remove_line_breaks"]] <-
+    case_switch(
+      knitr::is_latex_output() ~
+        expr(gt::cols_label_with(fn = function(x) gsub(x = x, pattern = "\\n(?!\\\\)", replacement = "", fixed = FALSE, perl = TRUE)))
+    )
+
+
   # tab_footnote ---------------------------------------------------------------
   if (nrow(x$table_styling$footnote) == 0 &&
     nrow(x$table_styling$footnote_abbrev) == 0) {
@@ -235,13 +245,11 @@ table_styling_to_gt_calls <- function(x, ...) {
         x$table_styling$footnote,
         x$table_styling$footnote_abbrev
       ) |>
-      tidyr::nest(data = c("column", "row_numbers")) %>%
-      dplyr::rowwise() %>%
+      tidyr::nest(row_numbers = "row_numbers") %>%
       dplyr::mutate(
-        columns = .data$data %>% dplyr::pull("column") %>% unique() %>% list(),
-        rows = .data$data %>% dplyr::pull("row_numbers") %>% unique() %>% list()
-      ) |>
-      dplyr::ungroup()
+        # columns = .data$data %>% dplyr::pull("column") %>% list(),
+        rows = map(.data$row_numbers, \(x) unlist(x) |> unname())
+      )
     df_footnotes$footnote_exp <-
       map2(
         df_footnotes$text_interpret,
@@ -254,14 +262,14 @@ table_styling_to_gt_calls <- function(x, ...) {
       pmap(
         list(
           df_footnotes$tab_location, df_footnotes$footnote_exp,
-          df_footnotes$columns, df_footnotes$rows
+          df_footnotes$column, df_footnotes$rows
         ),
-        function(tab_location, footnote, columns, rows) {
+        function(tab_location, footnote, column, rows) {
           if (tab_location == "header") {
             return(expr(
               gt::tab_footnote(
                 footnote = !!footnote,
-                locations = gt::cells_column_labels(columns = !!columns)
+                locations = gt::cells_column_labels(columns = !!column)
               )
             ))
           }
@@ -269,7 +277,7 @@ table_styling_to_gt_calls <- function(x, ...) {
             return(expr(
               gt::tab_footnote(
                 footnote = !!footnote,
-                locations = gt::cells_body(columns = !!columns, rows = !!rows)
+                locations = gt::cells_body(columns = !!column, rows = !!rows)
               )
             ))
           }
@@ -315,14 +323,18 @@ table_styling_to_gt_calls <- function(x, ...) {
 
   # tab_source_note  -----------------------------------------------------------
   # adding other calls from x$table_styling$source_note
-  if (!is.null(x$table_styling$source_note)) {
-    source_note <-
-      rlang::call2(
-        get(attr(x$table_styling$source_note, "text_interpret"), envir = asNamespace("gt")),
-        x$table_styling$source_note
-      )
-    gt_calls[["tab_source_note"]] <- expr(gt::tab_source_note(source_note = !!source_note))
-  }
+  gt_calls[["tab_source_note"]] <-
+    map(
+      seq_len(nrow(x$table_styling$source_note)),
+      \(i) {
+        expr(
+          gt::tab_source_note(source_note =
+                                !!do.call(eval(rlang::parse_expr(x$table_styling$source_note$text_interpret[i])),
+                                          args = list(x$table_styling$source_note$source_note[i])))
+        )
+      }
+    )
+
 
   # cols_hide ------------------------------------------------------------------
   gt_calls[["cols_hide"]] <-
