@@ -299,7 +299,7 @@ show_header_names <- function(x, include_example, quiet) {
 
   cat("\n")
   cli::cli_inform(c("* These values may be dynamically placed into headers (and other locations).",
-    "i" = "Review the {.help [{.fun modify_header}](gtsummary::modify)} help for examples."
+    "i" = "Review the {.help [{.fun modify_header}](gtsummary::modify_header)} help for examples."
   ))
 }
 
