@@ -1,21 +1,11 @@
-# tibble -----------------------------------------------------------------------
-#' @export
-#' @importFrom tibble as_tibble
-tibble::as_tibble
-
-# knitr ------------------------------------------------------------------------
-#' @export
-#' @importFrom knitr knit_print
-knitr::knit_print
-
 # dplyr ------------------------------------------------------------------------
 #' @export
 #' @importFrom dplyr %>%
 dplyr::`%>%`
 
-#' @importFrom dplyr vars
 #' @export
-dplyr::vars
+#' @importFrom dplyr as_tibble
+dplyr::as_tibble
 
 #' @importFrom dplyr select
 #' @export
@@ -61,6 +51,15 @@ dplyr::everything
 #' @export
 dplyr::last_col
 
+#' @importFrom dplyr where
+#' @export
+dplyr::where
+
 #' @importFrom dplyr one_of
 #' @export
 dplyr::one_of
+
+# Remove after Jan 1, 2025
+#' @importFrom dplyr vars
+#' @export
+dplyr::vars
