@@ -26,6 +26,8 @@ style_ratio <- function(x,
                         digits = 2,
                         big.mark = ifelse(decimal.mark == ",", " ", ","),
                         decimal.mark = getOption("OutDec"),
+                        prefix = "",
+                        suffix = "",
                         ...) {
   set_cli_abort_call()
 
@@ -42,11 +44,11 @@ style_ratio <- function(x,
   x_fmt <-
     dplyr::case_when(
       cards::round5(abs(x), digits = digits) < 1 ~
-        style_sigfig(x, digits = digits, big.mark = big.mark, decimal.mark = decimal.mark, ...),
+        style_sigfig(x, digits = digits, big.mark = big.mark, decimal.mark = decimal.mark, prefix = prefix, suffix = suffix, ...),
       x > 0 ~
-        style_sigfig(pmax(1, x), digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, ...),
+        style_sigfig(pmax(1, x), digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, prefix = prefix, suffix = suffix, ...),
       x < 0 ~
-        style_sigfig(pmin(-1, x), digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, ...),
+        style_sigfig(pmin(-1, x), digits = digits + 1, big.mark = big.mark, decimal.mark = decimal.mark, prefix = prefix, suffix = suffix, ...),
     )
 
   attributes(x_fmt) <- attributes(unclass(x))
