@@ -426,7 +426,7 @@ tbl_summary <- function(data,
   x
 }
 
-.add_gts_column_to_cards_summary <- function(cards, variables, by, hierarchical = FALSE) {
+.add_gts_column_to_cards_summary <- function(cards, variables, by) {
   if ("gts_column" %in% names(cards)) {
     cli::cli_inform("The {.val gts_column} column is alread present. Defining the column has been skipped.")
     return(cards)
@@ -440,16 +440,6 @@ tbl_summary <- function(data,
         "stat_0",
         NA_character_
       )
-  } else if (hierarchical) { # disregard hierarchies, only check by variable
-    cards <- cards |>
-      dplyr::group_by(.data$group1_level) |>
-      dplyr::mutate(gts_column = paste0("stat_", dplyr::cur_group_id()))
-
-    # process overall row
-    cards[cards$variable %in% by, ] <- cards[cards$variable %in% by, ] |>
-      dplyr::group_by(.data$variable_level) |>
-      dplyr::mutate(gts_column = paste0("stat_", dplyr::cur_group_id())) |>
-      dplyr::ungroup()
   } else {
     # styler: off
     cards <-
@@ -462,8 +452,8 @@ tbl_summary <- function(data,
           !cards$context %in% "attributes",
         ) |>
           dplyr::select(cards::all_ard_groups(), "variable", "context") |>
-          dplyr::distinct() |>
-          dplyr::arrange(unlist(!!sym("group1_level"))) |>
+          dplyr::distinct() %>%
+          {.[order(unlist(.$group1_level)), ]} |> # styler: off
           dplyr::mutate(
             .by = cards::all_ard_groups(),
             gts_column = paste0("stat_", dplyr::cur_group_id())
