@@ -84,6 +84,8 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
         "add_stat_label-arg:location" = "row",
         "tbl_summary-arg:statistic" = list(all_continuous() ~ "{median} ({p25} \U2013 {p75})",
                                            all_categorical() ~ "{n} ({p})"),
+        "tbl_svysummary-arg:statistic" = list(all_continuous() ~ "{median} ({p25} \U2013 {p75})",
+                                           all_categorical() ~ "{n} ({p})"),
         "tbl_summary-fn:addnl-fn-to-run" = function(x) {
           add_stat_label(x) |>
             modify_table_body(
@@ -95,6 +97,17 @@ theme_gtsummary_journal <- function(journal = c("jama", "lancet", "nejm", "qjeco
               }
             )
         },
+        "tbl_svysummary-fn:addnl-fn-to-run" = function(x) {
+          add_stat_label(x) |>
+            modify_table_body(
+              \(x) {
+                if ("stat_label" %in% names(x)) {
+                  x$stat_label <- gsub("Q1 \U2013 Q3", "IQR", x = x$stat_label)
+                }
+                x
+              }
+            )
+        },
         "add_difference-fn:addnl-fn-to-run" = function(x) {
           # merging coef and CI columns, if error, returning x unaltered
           tryCatch(
