@@ -1,6 +1,6 @@
 # add_p.tbl_summary ------------------------------------------------------------
 add_p_test_t.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -15,7 +15,7 @@ add_p_test_t.test <- function(data, variable, by, test.args, conf.level = 0.95,
 }
 
 add_p_test_wilcox.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -39,7 +39,7 @@ add_p_test_wilcox.test <- function(data, variable, by, test.args, conf.level = 0
 
 
 add_p_test_mcnemar.test <- function(data, variable, by, group, test.args, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -56,7 +56,7 @@ add_p_test_mcnemar.test <- function(data, variable, by, group, test.args, ...) {
 }
 
 add_p_test_mcnemar.test_wide <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -70,7 +70,7 @@ add_p_test_mcnemar.test_wide <- function(data, variable, by, test.args, ...) {
 }
 
 add_p_test_chisq.test <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -98,7 +98,7 @@ add_p_test_chisq.test.no.correct <- function(data, variable, by, test.args, ...)
 }
 
 add_p_test_mood.test <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -113,7 +113,7 @@ add_p_test_mood.test <- function(data, variable, by, test.args, ...) {
 
 
 add_p_test_kruskal.test <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars", "test.args"), ...)
 
   cardx::ard_stats_kruskal_test(
@@ -124,7 +124,7 @@ add_p_test_kruskal.test <- function(data, variable, by, ...) {
 }
 
 add_p_test_fisher.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -146,18 +146,17 @@ add_p_test_fisher.test <- function(data, variable, by, test.args, conf.level = 0
 }
 
 add_p_test_aov <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   cli::cli_warn(c(
     "The test {.val aov} in {.code add_p(test)} was deprecated in {.pkg gtsummary} 2.0.0.",
-    i = "The same functionality is covered with {.val oneway.test}. Use the following code instead:",
-    i = "{.code add_p(test = list({variable} = 'oneway.test'), test.args = list({variable} = list(var.equal = TRUE)))}."
+    i = "The same functionality is covered in {.val oneway.test} with argument `var.equal = TRUE`."
   ))
 
   add_p_test_oneway.test(data = data, variable = variable, by = by, test.args = list(var.equal = TRUE))
 }
 
 add_p_test_oneway.test <- function(data, variable, by, test.args, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -170,7 +169,7 @@ add_p_test_oneway.test <- function(data, variable, by, test.args, ...) {
 }
 
 add_p_test_mood.test <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars", "test.args"), ...)
 
   rlang::inject(
@@ -183,8 +182,8 @@ add_p_test_mood.test <- function(data, variable, by, ...) {
 }
 
 add_p_test_lme4 <- function(data, variable, by, group, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
-  check_pkg_installed("lme4", reference_pkg = "cardx")
+  check_pkg_installed("cardx")
+  check_pkg_installed("lme4", ref = "cardx")
   check_empty(c("test.args", "adj.vars"), ...)
 
   if (is_empty(group)) {
@@ -213,7 +212,7 @@ add_p_test_lme4 <- function(data, variable, by, group, ...) {
 
 
 add_p_tbl_summary_paired.t.test <- function(data, variable, by, group, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
   check_empty(c("adj.vars"), ...)
@@ -231,7 +230,7 @@ add_p_tbl_summary_paired.t.test <- function(data, variable, by, group, test.args
 }
 
 add_p_tbl_summary_paired.wilcox.test <- function(data, variable, by, group, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -249,7 +248,7 @@ add_p_tbl_summary_paired.wilcox.test <- function(data, variable, by, group, test
 }
 
 add_p_test_prop.test <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("adj.vars", "group"), ...)
 
   rlang::inject(
@@ -264,7 +263,7 @@ add_p_test_prop.test <- function(data, variable, by, test.args, conf.level = 0.9
 }
 
 add_p_test_ancova <- function(data, variable, by, adj.vars = NULL, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "test.args"), ...)
   check_n_levels(data[[by]], 2L, message = "The {.arg by} column must have {.val {length}} levels.")
 
@@ -308,7 +307,7 @@ add_p_test_ancova <- function(data, variable, by, adj.vars = NULL, ...) {
 
 
 add_p_test_cohens_d <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -324,7 +323,7 @@ add_p_test_cohens_d <- function(data, variable, by, test.args, conf.level = 0.95
 }
 
 add_p_test_paired_cohens_d <- function(data, variable, by, test.args, group, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -343,7 +342,7 @@ add_p_test_paired_cohens_d <- function(data, variable, by, test.args, group, con
 }
 
 add_p_test_hedges_g <- function(data, variable, by, test.args, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars"), ...)
 
   rlang::inject(
@@ -359,7 +358,7 @@ add_p_test_hedges_g <- function(data, variable, by, test.args, conf.level = 0.95
 }
 
 add_p_test_paired_hedges_g <- function(data, variable, by, test.args, group, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("adj.vars"), ...)
   check_length(group, 1L)
   warn_unbalanced_pairs(data, by, variable, group)
@@ -378,7 +377,7 @@ add_p_test_paired_hedges_g <- function(data, variable, by, test.args, group, con
 }
 
 add_p_test_smd <- function(data, variable, by, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("group", "adj.vars", "test.args"), ...)
 
   cardx::ard_smd_smd(
@@ -391,11 +390,11 @@ add_p_test_smd <- function(data, variable, by, ...) {
 
 add_p_test_emmeans <- function(data, variable, by, adj.vars = NULL, conf.level = 0.95,
                                type, group = NULL, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
 
-  if (!is_empty(group)) check_pkg_installed("lme4", reference_pkg = "cardx")
-  if (inherits(data, "survey.design")) check_pkg_installed("survey", reference_pkg = "cardx")
+  if (!is_empty(group)) check_pkg_installed("lme4", ref = "cardx")
+  if (inherits(data, "survey.design")) check_pkg_installed("survey", ref = "cardx")
 
   # checking inputs
   if (!type %in% c("continuous", "dichotomous")) {
@@ -467,7 +466,7 @@ add_p_test_emmeans <- function(data, variable, by, adj.vars = NULL, conf.level =
 }
 
 add_p_test_ancova_lme4 <- function(data, variable, by, group, conf.level = 0.95, adj.vars = NULL, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
   check_length(group, 1L)
 
@@ -518,7 +517,7 @@ add_p_test_ancova_lme4 <- function(data, variable, by, group, conf.level = 0.95,
 
 # tbl_svysummary ---------------------------------------------------------------
 add_p_test_svy.t.test <- function(data, variable, by, conf.level = 0.95, ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
 
   cardx::ard_survey_svyttest(
@@ -533,7 +532,7 @@ add_p_test_svy.svyranktest <- function(data,
                                        variable,
                                        by,
                                        test = c("wilcoxon", "vanderWaerden", "median", "KruskalWallis"), ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
   test <- arg_match(test)
 
@@ -551,7 +550,7 @@ add_p_test_svychisq.test <- function(data,
                                       by,
                                       statistic = c("F", "Chisq", "Wald", "adjWald", "lincom",
                                                     "saddlepoint", "wls-score"), ...) {
-  check_pkg_installed("cardx", reference_pkg = "gtsummary")
+  check_pkg_installed("cardx")
   check_empty(c("test.args"), ...)
   statistic <- arg_match(statistic)
 
@@ -593,6 +592,10 @@ add_p_test_tbl_summary_to_tbl_continuous <- function(data, variable, by, continu
            data = data, variable = continuous_variable,
            by = variable, test.args = test.args, ...
          ),
+         "oneway.test" = add_p_test_oneway.test(
+           data = data, variable = continuous_variable,
+           by = variable, test.args = test.args, ...
+         ),
          "kruskal.test" = add_p_test_kruskal.test(
            data = data, variable = continuous_variable,
            by = variable, test.args = test.args, ...
@@ -631,7 +634,7 @@ extract_formula_data_call <- function(x) {
 }
 
 add_p_tbl_survfit_survdiff <- function(data, variable, test.args, ...) {
-  check_pkg_installed(c("cardx", "survival"), reference_pkg = "gtsummary")
+  check_pkg_installed(c("cardx", "survival"))
 
   # formula and data calls
   formula_data_call <-
@@ -655,7 +658,7 @@ add_p_tbl_survfit_petopeto_gehanwilcoxon <- function(data, variable, ...) {
 }
 
 add_p_tbl_survfit_coxph <- function(data, variable, test_type = c("log", "sc", "wald"), test.args, ...) {
-  check_pkg_installed(c("cardx", "survival", "broom"), reference_pkg = "gtsummary")
+  check_pkg_installed(c("cardx", "survival", "broom"))
   test_type <- arg_match(test_type)
 
   # formula and data calls
