@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("cardx", reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed("cardx"))
 
 test_that("add_p.tbl_continuous() works", {
   expect_silent(
@@ -59,20 +59,29 @@ test_that("add_p.tbl_continuous(include) works", {
 test_that("add_p.tbl_continuous(test.args) works", {
   expect_silent(
     tbl3 <- trial |>
-      tbl_continuous(variable = age, include = trt) |>
-      add_p(test = trt ~ "t.test", test.args = all_tests("t.test") ~ list(var.equal = TRUE))
+      tbl_continuous(variable = age, include = c(trt, grade)) |>
+      add_p(
+        test = list(trt = "t.test", grade = "oneway.test"),
+        test.args =
+          c(all_tests("t.test"), all_tests("oneway.test")) ~ list(var.equal = TRUE)
+      )
   )
 
-  compare <- t.test(age ~ trt, trial, var.equal = TRUE)
+  compare_t.test <- t.test(age ~ trt, trial, var.equal = TRUE)
+  compare_oneway.test <- oneway.test(age ~ grade, trial, var.equal = TRUE)
 
   expect_equal(
-    tbl3$table_body$p.value[1],
-    compare$p.value
+    tbl3$table_body |> dplyr::filter(variable == "trt") |> dplyr::pull("p.value") |> getElement(1),
+    compare_t.test$p.value
+  )
+  expect_equal(
+    tbl3$table_body |> dplyr::filter(variable == "grade") |> dplyr::pull("p.value") |> getElement(1),
+    compare_oneway.test$p.value
   )
 })
 
 test_that("add_p.tbl_continuous(group) works", {
-  skip_if_not(is_pkg_installed("lme4", reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed("lme4"))
 
   expect_silent(
     tbl4 <- trial |>
@@ -102,3 +111,11 @@ test_that("add_p.tbl_continuous(group) works", {
     unlist(compare)
   )
 })
+
+test_that("add_p.tbl_continuous() messaging", {
+  expect_message(
+    tbl_continuous(trial, variable = age, include = grade) |>
+      add_p(test = ~"lme4"),
+    "*argument cannot be missing*"
+  )
+})
