@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed(c("cardx", "survival", "broom"), reference_pkg = "cardx"))
+skip_if_not(is_pkg_installed(c("cardx", "survival", "broom"), ref = "cardx"))
 
 test_that("add_p.tbl_survfit() works", {
   tbl <- trial |>
