@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("knitr", reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed("knitr"))
 
 my_tbl_summary <- trial |>
   select(trt, age, death) |>
@@ -121,7 +121,7 @@ test_that("as_kable works with tbl_uvregression", {
 })
 
 test_that("as_kable works with tbl_survfit", {
-  skip_if_not(is_pkg_installed("survival", reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed("survival"))
 
   fit1 <- survival::survfit(survival::Surv(ttdeath, death) ~ trt, trial)
   tbl <- tbl_survfit(fit1, times = c(12, 24), label_header = "{time} Months")
@@ -131,7 +131,7 @@ test_that("as_kable works with tbl_survfit", {
 })
 
 test_that("as_kable works with tbl_merge", {
-  skip_if_not(is_pkg_installed("survival", reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed("survival"))
 
   t1 <- glm(response ~ trt + grade + age, trial, family = binomial) |>
     tbl_regression(exponentiate = TRUE)
