@@ -1,5 +1,5 @@
 skip_on_cran()
-skip_if_not(is_pkg_installed("survival", reference_pkg = "gtsummary"))
+skip_if_not(is_pkg_installed("survival"))
 
 # inline_text.tbl_summary tests ------------------------------------------------
 test_inline1 <- trial |> tbl_summary()
