@@ -272,7 +272,7 @@ test_that("tbl_strata2(.quiet) produces deprecation warning", {
 })
 
 test_that("tbl_strata works with survey objects", {
-  skip_if_not(is_pkg_installed("survey", reference_pkg = "gtsummary"))
+  skip_if_not(is_pkg_installed("survey"))
 
   svy_obj <- survey::svydesign(~1, data = trial, weights = ~1)
 
